biometry_scanner_widget library

A guided video-capture camera widget for the biometric verification flow — see BiometryScannerWidget.

Classes

BiometryScannerWidget
A widget that records a video of the user's face while displaying a phrase. Once the user starts talking (simulated by auto-start after 1 second), it displays the words of the phrase one by one. When all words are shown, the recording stops and the captured video is returned.
BiometryScannerWidgetState
The state of the BiometryScannerWidget.
TimerBorderPainter
Custom painter that draws a circular progress border.