biometry library
Biometric authentication and identity verification against the Biometry v2 API — see Biometry for the main entry point.
Classes
- Biometry
- A class to handle biometry-related operations against the Biometry v2 API.
- ConsentApproval
- A single consent approval record, as returned by Biometry.getConsentApprovals.